@@ -10,8 +10,8 @@ from time import timezone, sleep
 from typing import BinaryIO
 from binascii import hexlify
 from time import time as timestamp
-from locale import getdefaultlocale as local
-
+from locale import getdefaultlocale as locale
+from .d import devicee
 from .lib.util import exceptions, headers, device, objects, helpers
 from .socket import Callbacks, SocketHandler
 
@@ -40,8 +40,7 @@ class Client(Callbacks, SocketHandler):
         self.reg_headers=headers.Headers().reg_headers
         self.account: objects.UserProfile = objects.UserProfile(None)
         self.profile: objects.UserProfile = objects.UserProfile(None)
-        #self.check_device(self.device_id)
-        #rint(self.device_id)
+        self.check_device(self.device_id)
         
     def parse_headers(self, data = None):
         if data:
@@ -288,6 +287,13 @@ class Client(Callbacks, SocketHandler):
         if response.status_code != 200: return exceptions.CheckException(json.loads(response.text))
         else: return response.status_code
 
+    def get_dev(self):
+        try:
+            deviceId=devicee()
+        except Exception:
+            deviceId="179E40A520E48AF9F994B1E4FAEAEAE6E9BD04D109635AFC96258A96187C3CC551B21A889900F12A81"
+        return deviceId
+
     def logout(self):
         """
         Logout from an account.
@@ -673,58 +679,7 @@ class Client(Callbacks, SocketHandler):
     	       	pass
     	       	return shown
 
-    def check(self,email : str):
-      data=json.dumps({'email': email})
-      req=requests.post("https://aminoapps.com/api/register-check",data=data,headers=self.reg_headers)
-      if req.status_code != 200 : raise TypeError(req.text)
-      return json.loads(req.text)
-      
-    def check_code(self,email : str,code : str):
-        data=json.dumps({
-        'validationContext':{'data': {'code': code},
-        'identity': email,
-        'type': 1,
-        'verifyInfoKey': None}})
-        req=requests.post("https://aminoapps.com/api/auth/check-security-validation",data=data,headers=self.reg_headers)
-        if req.status_code != 200 : raise TypeError(req.text)
-        return json.loads(req.text)
-        
-    def register_check(self,email : str,password : str):
-      data=json.dumps({
-      'email': email,
-      'phoneNumber': "",
-      'secret': "hhhhhh"
-      })
-      req=requests.post("https://aminoapps.com/api/register-check",data=data,headers=self.reg_headers)
-      if req.status_code != 200 : raise TypeError(req.text)
-      return json.loads(req.text)
     
-    def register_g(self,email : str, password : str,nickname : str,code : str):
-        data=({
-        'email': email,
-        'nickname': nickname,
-        'phoneNumber': "",
-        'secret2': password,
-        'validationContext': {
-            'data': {'code': code},
-            'code': code,
-            'identity': email,
-            'type': 1,
-            '__original':{
-                'data': {'code': code},
-                'code': code,
-                'identity': email,
-                'type' : 1,
-                '__response': {}
-        }}}) ; 
-        req=requests.post("https://aminoapps.com/api/register",json=data,headers=self.web_headers)
-        #print(req.text)
-        try:
-            if req.json()["result"]['api:message'] != "OK":
-                print(req.text)
-        except:
-            print(req.text)
-        print("Account Created")
     
     def verify_code(self,email):
         #while True:
@@ -739,7 +694,7 @@ class Client(Callbacks, SocketHandler):
     	self.request_verify_code(email = email)
     	print('Verification Code Sent')
     	vcode=self.verify_code(email)
-    	self.register_g(email = email,password = password,nickname = nickname,code = vcode)
+    	self.register(email = email,password = password,nickname = nickname,verificationCode = vcode)
     	return email
 
     def leave_chat(self, chatId: str):
